@@ -484,6 +484,8 @@ class Door(_BaseWithShade):
         Returns:
             True if geometrically equivalent. False if not geometrically equivalent.
         """
+        if abs(self.area - door.area) > tolerance * self.area:
+            return False
         return self.geometry.is_centered_adjacent(door.geometry, tolerance)
 
     def check_planar(self, tolerance=0.01, raise_exception=True, detailed=False):
